==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Test/Gui/Resources/translations/Test_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Selhání a chyby</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Popis</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Spustit</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>ALT + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>Nápověda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;O</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Zavřít</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Nečinný</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Průběh</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt; 0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Zbývá:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Chyby:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Selhání:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Běží:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Vyberte testovací jméno:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Nápověda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>O FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer FreeCAD UnitTest je součástí FreeCAD a podporuje psaní Unit testů pro vlastní moduly.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Zadejte název volatelného objektu, který při volání, vrátí TestCase. Klikněte 'start' a takto vytvořeny test bude spuštěn.

Poklepáním na chybu ve stromovém zobrazení zobrazíte další informace o chybě, včetně zásobníku.</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Test/Gui/Resources/translations/Test_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Selhání a chyby</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Popis</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Spustit</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>ALT + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>Nápověda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;O</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Zavřít</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Nečinný</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Průběh</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt; 0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Zbývá:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Chyby:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Selhání:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Běží:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Vyberte testovací jméno:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Nápověda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>O FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest je součástí FreeCAD a podporuje psaní Unit testů pro vlastní moduly.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Zadejte název volatelného objektu, který při volání, vrátí TestCase. Klikněte 'start' a takto vytvořeny test bude spuštěn.

Poklepáním na chybu ve stromovém zobrazení zobrazíte další informace o chybě, včetně zásobníku.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation type="unfinished">Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation type="unfinished">Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</translation>
    </message>
  </context>
</TS>
